@@ -18,7 +18,7 @@ import certifi
 from cyberdrop_dl.downloader.progress_definitions import file_progress
 from .rate_limiting import AsyncRateLimiter, throttle
 from ..base_functions.base_functions import logger
-from ..base_functions.data_classes import FileLock, MediaItem
+from ..base_functions.data_classes import MediaItem
 from ..base_functions.error_classes import DownloadFailure, InvalidContentTypeFailure
 
 
@@ -29,7 +29,7 @@ class Client:
         self.ratelimit = ratelimit
         self.throttle = throttle
         self.simultaneous_session_limit = asyncio.Semaphore(50)
-        self.user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/109.0'
+        self.user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:109.0) Gecko/20100101 Firefox/110.0'
         self.verify_ssl = secure
         self.ssl_context = ssl.create_default_context(cafile=certifi.where()) if secure else False
         self.cookies = aiohttp.CookieJar(quote_cookie=False)
@@ -41,7 +41,7 @@ class ScrapeSession:
         self.client = client
         self.rate_limiter = AsyncRateLimiter(self.client.ratelimit)
         self.headers = {"user-agent": client.user_agent}
-        self.timeouts = aiohttp.ClientTimeout(total=5 * 60, connect=self.client.connect_timeout)
+        self.timeouts = aiohttp.ClientTimeout(total=5 * 60, connect=self.client.connect_timeout, sock_read=30)
         self.client_session = aiohttp.ClientSession(headers=self.headers, raise_for_status=True, cookie_jar=self.client.cookies, timeout=self.timeouts)
 
     async def get_BS4(self, url: URL):
@@ -95,13 +95,13 @@ class ScrapeSession:
     async def get_no_resp(self, url: URL, headers: dict):
         async with self.client.simultaneous_session_limit:
             async with self.rate_limiter:
-                async with self.client_session.get(url, headers=headers, ssl=self.client.ssl_context) as response:
+                async with self.client_session.get(url, headers=headers, ssl=self.client.ssl_context):
                     pass
 
     async def post_data_no_resp(self, url: URL, data: dict):
         async with self.client.simultaneous_session_limit:
             async with self.rate_limiter:
-                async with self.client_session.post(url, data=data, headers=self.headers, ssl=self.client.ssl_context) as response:
+                async with self.client_session.post(url, data=data, headers=self.headers, ssl=self.client.ssl_context):
                     pass
 
     async def exit_handler(self):
@@ -121,14 +121,15 @@ class DownloadSession:
         self.throttle_times = {}
 
     async def download_file(self, media: MediaItem, file: Path, current_throttle: int, resume_point: int,
-                            File_Lock: FileLock, proxy: str, headers: dict, original_filename: str,
-                            file_task: TaskID):
+                            proxy: str, headers: dict, file_task: TaskID):
         headers['Referer'] = str(media.referer)
         headers['user-agent'] = self.client.user_agent
         await throttle(self, current_throttle, media.url.host)
         async with self.client_session.get(media.url, headers=headers, ssl=self.client.ssl_context,
                                            raise_for_status=True, proxy=proxy) as resp:
             content_type = resp.headers.get('Content-Type')
+            if not content_type:
+                raise DownloadFailure(code=418, message="No content-type in response header")
             if resp.url == URL("https://bnkr.b-cdn.net/maintenance.mp4"):
                 raise DownloadFailure(code=503, message="Bunkr under maintenance")
             if 'text' in content_type.lower() or 'html' in content_type.lower():
@@ -148,13 +149,15 @@ class DownloadSession:
                     file_progress.advance(file_task, len(chunk))
 
     async def old_download_file(self, media: MediaItem, file: Path, current_throttle: int, resume_point: int,
-                            File_Lock: FileLock, proxy: str, headers: dict, original_filename: str):
+                                proxy: str, headers: dict):
         headers['Referer'] = str(media.referer)
         headers['user-agent'] = self.client.user_agent
         await throttle(self, current_throttle, media.url.host)
         async with self.client_session.get(media.url, headers=headers, ssl=self.client.ssl_context,
                                            raise_for_status=True, proxy=proxy) as resp:
             content_type = resp.headers.get('Content-Type')
+            if not content_type:
+                raise DownloadFailure(code=418, message="No content-type in response header")
             if resp.url == URL("https://bnkr.b-cdn.net/maintenance.mp4"):
                 raise DownloadFailure(code=503, message="Bunkr under maintenance")
             if 'text' in content_type.lower() or 'html' in content_type.lower():
