@@ -63,6 +63,11 @@ class Files:
         self.failed_files_task_id = failed
         self.failed_files = 0
 
+    async def hide(self):
+        overall_file_progress.update(self.completed_files_task_id, visible=False)
+        overall_file_progress.update(self.skipped_files_task_id, visible=False)
+        overall_file_progress.update(self.failed_files_task_id, visible=False)
+
 
 class Downloader:
     """Downloader class, directs downloading for domain objects"""
@@ -250,7 +255,7 @@ class Downloader:
         except (aiohttp.client_exceptions.ClientPayloadError, aiohttp.client_exceptions.ClientOSError,
                 aiohttp.client_exceptions.ServerDisconnectedError, asyncio.TimeoutError,
                 aiohttp.client_exceptions.ClientResponseError, aiohttp.client_exceptions.ServerTimeoutError,
-                DownloadFailure, PermissionError) as e:
+                DownloadFailure, FileNotFoundError, PermissionError) as e:
             if await self.File_Lock.check_lock(original_filename):
                 await self.File_Lock.remove_lock(original_filename)
 
@@ -376,6 +381,10 @@ async def download_cascade(args: dict, Cascade: CascadeItem, SQL_Helper: SQLHelp
             tasks.append(downloader.start_domain(cascade_task))
         await asyncio.gather(*tasks)
 
+        cascade_progress.update(cascade_task, visible=False)
+
+    await files.hide()
+
     await clear()
     await log(f"| [green]Files Complete: {files.completed_files}[/green] - [yellow]Files Skipped: "
               f"{files.skipped_files}[/yellow] - [red]Files Failed: {files.failed_files}[/red] |")
